@@ -4,7 +4,7 @@
  * radiusd.h	Structures, prototypes and global variables
  *		for the FreeRADIUS server.
  *
- * Version:	$Id: db05e25cb8a0194e11c453129f2ee235ad7e9ce5 $
+ * Version:	$Id: 471c9223b80daed4a8c4d727769a13c0c0153b78 $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  */
 
 #include <freeradius/ident.h>
-RCSIDH(radiusd_h, "$Id: db05e25cb8a0194e11c453129f2ee235ad7e9ce5 $")
+RCSIDH(radiusd_h, "$Id: 471c9223b80daed4a8c4d727769a13c0c0153b78 $")
 
 #include <freeradius/libradius.h>
 #include <freeradius/radpaths.h>
@@ -360,7 +360,7 @@ typedef struct main_config_t {
 	int		proxy_requests;
 	int		reject_delay;
 	int		status_server;
-#ifdef ENABLE_OPENSSL_VERSION_CHECK
+#if defined(HAVE_OPENSSL_CRYPTO_H) && defined(ENABLE_OPENSSL_VERSION_CHECK)
 	int		allow_vulnerable_openssl;
 #endif
 	int		max_request_time;
@@ -536,7 +536,8 @@ int		pairlist_read(const char *file, PAIR_LIST **list, int complain);
 void		pairlist_free(PAIR_LIST **);
 
 /* version.c */
-int 		ssl_check_version(int allow_vulnerable);
+int 		ssl_check_version(void);
+int 		ssl_check_vulnerable(void);
 const char	*ssl_version(void);
 void		version(void);
 
